==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/storageactions/kotlin/inputs/ElseConditionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.storageactions.kotlin.inputs

import com.pulumi.azurenative.storageactions.inputs.ElseConditionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The else block of storage task operation
 * @property operations List of operations to execute in the else block
 */
public data class ElseConditionArgs(
    public val operations: Output<List<StorageTaskOperationArgs>>,
) : ConvertibleToJava<com.pulumi.azurenative.storageactions.inputs.ElseConditionArgs> {
    override fun toJava(): com.pulumi.azurenative.storageactions.inputs.ElseConditionArgs =
        com.pulumi.azurenative.storageactions.inputs.ElseConditionArgs.builder()
            .operations(
                operations.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ElseConditionArgs].
 */
@PulumiTagMarker
public class ElseConditionArgsBuilder internal constructor() {
    private var operations: Output<List<StorageTaskOperationArgs>>? = null

    /**
     * @param value List of operations to execute in the else block
     */
    @JvmName("jehweagqtghypqnh")
    public suspend fun operations(`value`: Output<List<StorageTaskOperationArgs>>) {
        this.operations = value
    }

    @JvmName("kupadwjdwwfdpntg")
    public suspend fun operations(vararg values: Output<StorageTaskOperationArgs>) {
        this.operations = Output.all(values.asList())
    }

    /**
     * @param values List of operations to execute in the else block
     */
    @JvmName("sdjmyxpystviticg")
    public suspend fun operations(values: List<Output<StorageTaskOperationArgs>>) {
        this.operations = Output.all(values)
    }

    /**
     * @param value List of operations to execute in the else block
     */
    @JvmName("mneejxqrqhxphhma")
    public suspend fun operations(`value`: List<StorageTaskOperationArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.operations = mapped
    }

    /**
     * @param argument List of operations to execute in the else block
     */
    @JvmName("jkrgpgcjcxrrmnwb")
    public suspend
    fun operations(argument: List<suspend StorageTaskOperationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            StorageTaskOperationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.operations = mapped
    }

    /**
     * @param argument List of operations to execute in the else block
     */
    @JvmName("kbjxofwngoqdqflp")
    public suspend fun operations(
        vararg
        argument: suspend StorageTaskOperationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            StorageTaskOperationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.operations = mapped
    }

    /**
     * @param argument List of operations to execute in the else block
     */
    @JvmName("bfcskhgvqiksjteu")
    public suspend fun operations(argument: suspend StorageTaskOperationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(StorageTaskOperationArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.operations = mapped
    }

    /**
     * @param values List of operations to execute in the else block
     */
    @JvmName("inbitgtawmnhrqjb")
    public suspend fun operations(vararg values: StorageTaskOperationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.operations = mapped
    }

    internal fun build(): ElseConditionArgs = ElseConditionArgs(
        operations = operations ?: throw PulumiNullFieldException("operations"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/storageactions/kotlin/inputs/ElseConditionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.storageactions.kotlin.inputs

import com.pulumi.azurenative.storageactions.inputs.ElseConditionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The else block of storage task operation
 * @property operations List of operations to execute in the else block
 */
public data class ElseConditionArgs(
    public val operations: Output<List<StorageTaskOperationArgs>>,
) : ConvertibleToJava<com.pulumi.azurenative.storageactions.inputs.ElseConditionArgs> {
    override fun toJava(): com.pulumi.azurenative.storageactions.inputs.ElseConditionArgs =
        com.pulumi.azurenative.storageactions.inputs.ElseConditionArgs.builder()
            .operations(
                operations.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ElseConditionArgs].
 */
@PulumiTagMarker
public class ElseConditionArgsBuilder internal constructor() {
    private var operations: Output<List<StorageTaskOperationArgs>>? = null

    /**
     * @param value List of operations to execute in the else block
     */
    @JvmName("bwacxrmgnjgxtvuy")
    public suspend fun operations(`value`: Output<List<StorageTaskOperationArgs>>) {
        this.operations = value
    }

    @JvmName("gbajpotgtxxlbxph")
    public suspend fun operations(vararg values: Output<StorageTaskOperationArgs>) {
        this.operations = Output.all(values.asList())
    }

    /**
     * @param values List of operations to execute in the else block
     */
    @JvmName("hclyopvveqcdsfjy")
    public suspend fun operations(values: List<Output<StorageTaskOperationArgs>>) {
        this.operations = Output.all(values)
    }

    /**
     * @param value List of operations to execute in the else block
     */
    @JvmName("kjntrhkqugqtvkoh")
    public suspend fun operations(`value`: List<StorageTaskOperationArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.operations = mapped
    }

    /**
     * @param argument List of operations to execute in the else block
     */
    @JvmName("jjcglgitpyjykcid")
    public suspend
    fun operations(argument: List<suspend StorageTaskOperationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            StorageTaskOperationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.operations = mapped
    }

    /**
     * @param argument List of operations to execute in the else block
     */
    @JvmName("hcfroalluffcdtlv")
    public suspend fun operations(
        vararg
        argument: suspend StorageTaskOperationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            StorageTaskOperationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.operations = mapped
    }

    /**
     * @param argument List of operations to execute in the else block
     */
    @JvmName("cyeihfrosawjkdky")
    public suspend fun operations(argument: suspend StorageTaskOperationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(StorageTaskOperationArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.operations = mapped
    }

    /**
     * @param values List of operations to execute in the else block
     */
    @JvmName("vuoqxejbrwhxenat")
    public suspend fun operations(vararg values: StorageTaskOperationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.operations = mapped
    }

    internal fun build(): ElseConditionArgs = ElseConditionArgs(
        operations = operations ?: throw PulumiNullFieldException("operations"),
    )
}
